Poem Text Generation (poemgen.py, jolastic.py)
==============================================

   |

These functions generate the actual text of poems.

.. automodule:: generativepoetry.poemgen
   :members:

.. autoclass:: generativepoetry.poemgen.Poem
   :members

.. autoclass:: generativepoetry.poemgen.PoemGenerator
   :members

.. automodule:: generativepoetry.jolastic
   :members:

.. autoclass:: generativepoetry.jolastic.StochasticJolasticWordGenerator
   :members